@@ -8,7 +8,6 @@ import termios
 import tty
 from dataclasses import dataclass, field
 from typing import List, Optional, TextIO, Tuple, Union
-from shared_utils import hard_exit
 
 tees = []
 
@@ -25,7 +24,6 @@ class Tee:
         tees.append(self)  # Do not let this get GC'd
         self.orig_stdout = _dup(sys.stdout)
         self.orig_stderr = _dup(sys.stderr)
-        hard_exit.register_atexit(self.close)
 
     def to(self, stdout, stderr):
         if not isinstance(stdout, list):
@@ -54,15 +52,13 @@ class Tee:
         # the redirected stdout/stderr, the tee processes will not
         # die. In that case maybe we should set a timeout, or just
         # leak them? Not sure.
-        if old_stdout_pipe_proc is not None:
-            pipe, proc = old_stdout_pipe_proc
+        if stdout_pipe_proc is not None:
+            pipe, proc = stdout_pipe_proc
             pipe.close()
-            os.kill(signal.SIGINT, proc.pid)
             proc.wait()
-        if old_stderr_pipe_proc is not None:
-            pipe, proc = old_stderr_pipe_proc
+        if stderr_pipe_proc is not None:
+            pipe, proc = stderr_pipe_proc
             pipe.close()
-            os.kill(signal.SIGINT, proc.pid)
             proc.wait()
 
     def resume(self):
@@ -94,12 +90,14 @@ def _tee(src, to, stdout):
         fcntl.ioctl(r, termios.TIOCSWINSZ, packed)
 
         def set_ctty():
+            signal.signal(signal.SIGINT, signal.SIG_IGN)
             w.close()
             fcntl.ioctl(r, termios.TIOCSCTTY, 0)
 
     else:
 
         def set_ctty():
+            signal.signal(signal.SIGINT, signal.SIG_IGN)
             w.close()
 
     for path in to:
